import { compose, tail, split } from 'ramda'
import decodePath from './decodePath'

/**
 * Convert a path into a list of strings.
 * Useful when traversing a path on a JSON Document
 *
 * ** Sig: String -> Array[String]
 *
 * @function
 * @param {string} path - A valid path that will be converted to an array
 * @returns {array} result - An array with the path names
 * @example
 *
 * listPath('/foo/bar') // ['foo', 'bar']
 * listPath('/foo~1bar~0/1') // ['foo', 'bar~', 1]
 */
const listPath = compose(tail, split('/'), decodePath)

export default listPath
